@@ -19,7 +19,7 @@
  * including the two.
  *
  * You must obey the GNU Affero General Public License in all respects
- * for all of the code used other than OpenSSL.  
+ * for all of the code used other than OpenSSL.
  */
 
 
@@ -160,7 +160,7 @@ bool Net_abort(int socket) {
    	int r;
         struct linger linger = {1, 0};
         if (setsockopt(socket, SOL_SOCKET, SO_LINGER, &linger, sizeof linger) < 0) {
-                ERROR("Net: setsockopt failed -- %s\n", System_getLastError());
+                ERROR("Net: setsockopt failed -- %s\n", System_lastError());
         }
         do {
                 r = close(socket);
