@@ -301,15 +301,15 @@ static bool _getDevice(Info_T inf, const char *path, bool (*compare)(const char
 
 
 bool Filesystem_getByMountpoint(Info_T inf, const char *path) {
-        ASSERT(inf);
-        ASSERT(path);
+        assert(inf);
+        assert(path);
         return _getDevice(inf, path, _compareMountpoint);
 }
 
 
 bool Filesystem_getByDevice(Info_T inf, const char *path) {
-        ASSERT(inf);
-        ASSERT(path);
+        assert(inf);
+        assert(path);
         return _getDevice(inf, path, _compareDevice);
 }
 
