@@ -60,10 +60,6 @@
 #include <unistd.h>
 #endif
 
-#ifdef HAVE_COREFOUNDATION_COREFOUNDATION_H
-#include <CoreFoundation/CoreFoundation.h>
-#endif
-
 #include "monit.h"
 #include "event.h"
 #include "ProcessTree.h"
@@ -75,13 +71,6 @@
 #include "system/Time.h"
 
 
-/**
- *  General purpose /proc methods.
- *
- *  @file
- */
-
-
 /* ------------------------------------------------------------- Definitions */
 
 
@@ -93,7 +82,7 @@ static ProcessTree_T *ptree = NULL;
 
 
 static void _delete(ProcessTree_T **pt, int *size) {
-        ASSERT(pt);
+        assert(pt);
         ProcessTree_T *_pt = *pt;
         if (_pt) {
                 for (int i = 0; i < *size; i++) {
@@ -167,12 +156,12 @@ static void _fillProcessTree(ProcessTree_T *pt, int index) {
  * @return Process's CPU usage [%] since last cycle
  */
 static float _cpuUsage(float rawUsage, unsigned int threads) {
-        if (systeminfo.cpu.count > 0 && rawUsage > 0) {
+        if (System_Info.cpu.count > 0 && rawUsage > 0) {
                 int divisor;
                 if (threads > 1) {
-                        if (threads >= (unsigned)systeminfo.cpu.count) {
+                        if (threads >= (unsigned)System_Info.cpu.count) {
                                 // Multithreaded application with more threads then CPU cores
-                                divisor = systeminfo.cpu.count;
+                                divisor = System_Info.cpu.count;
                         } else {
                                 // Multithreaded application with less threads then CPU cores
                                 divisor = threads;
@@ -192,7 +181,10 @@ static int _match(regex_t *regex) {
         int found = -1;
         // Scan the whole process tree and find the oldest matching process whose parent doesn't match the pattern
         for (int i = 0; i < ptreesize; i++)
-                if (ptree[i].cmdline && regexec(regex, ptree[i].cmdline, 0, NULL, 0) == 0 && (i == ptree[i].parent || ! ptree[ptree[i].parent].cmdline || regexec(regex, ptree[ptree[i].parent].cmdline, 0, NULL, 0) != 0) && (found == -1 || ptree[found].uptime < ptree[i].uptime))
+                if (ptree[i].cmdline
+                    && regexec(regex, ptree[i].cmdline, 0, NULL, 0) == 0
+                    && (i == ptree[i].parent || ! ptree[ptree[i].parent].cmdline || regexec(regex, ptree[ptree[i].parent].cmdline, 0, NULL, 0) != 0)
+                    && (found == -1 || ptree[found].uptime < ptree[i].uptime))
                         found = i;
         return found >= 0 ? ptree[found].pid : -1;
 }
@@ -219,9 +211,9 @@ int ProcessTree_init(ProcessEngine_Flags pflags) {
                 }
         }
 
-        systeminfo.time_prev = systeminfo.time;
-        systeminfo.time = Time_milli() / 100.;
-        if ((ptreesize = initprocesstree_sysdep(&ptree, pflags)) <= 0 || ! ptree) {
+        System_Info.time_prev = System_Info.time;
+        System_Info.time = Time_milli() / 100.;
+        if ((ptreesize = init_processtree_sysdep(&ptree, pflags)) <= 0 || ! ptree) {
                 DEBUG("System statistic -- cannot initialize the process tree -- process resource monitoring disabled\n");
                 Run.flags &= ~Run_ProcessEngineEnabled;
                 if (oldptree)
@@ -234,13 +226,13 @@ int ProcessTree_init(ProcessEngine_Flags pflags) {
 
         int root = -1; // Main process. Not all systems have main process with PID 1 (such as Solaris zones and FreeBSD jails), so we try to find process which is parent of itself
         ProcessTree_T *pt = ptree;
-        double time_delta = systeminfo.time - systeminfo.time_prev;
+        double time_delta = System_Info.time - System_Info.time_prev;
         for (int i = 0; i < (volatile int)ptreesize; i ++) {
                 pt[i].cpu.usage.self = -1;
                 if (oldptree) {
                         int oldentry = _findProcess(pt[i].pid, oldptree, oldptreesize);
                         if (oldentry != -1) {
-                                if (systeminfo.cpu.count > 0 && time_delta > 0 && oldptree[oldentry].cpu.time >= 0 && pt[i].cpu.time >= oldptree[oldentry].cpu.time) {
+                                if (System_Info.cpu.count > 0 && time_delta > 0 && oldptree[oldentry].cpu.time >= 0 && pt[i].cpu.time >= oldptree[oldentry].cpu.time) {
                                         pt[i].cpu.usage.self = 100. * (pt[i].cpu.time - oldptree[oldentry].cpu.time) / time_delta;
                                 }
                         }
@@ -282,13 +274,13 @@ int ProcessTree_init(ProcessEngine_Flags pflags) {
 /**
  * Delete the process tree
  */
-void ProcessTree_delete() {
+void ProcessTree_delete(void) {
         _delete(&ptree, &ptreesize);
 }
 
 
 bool ProcessTree_updateProcess(Service_T s, pid_t pid) {
-        ASSERT(s);
+        assert(s);
 
         /* save the previous pid and set actual one */
         s->inf.process->_pid = s->inf.process->pid;
@@ -324,9 +316,9 @@ bool ProcessTree_updateProcess(Service_T s, pid_t pid) {
                 s->inf.process->filedescriptors.openTotal   = ptree[leaf].filedescriptors.usage_total;
                 s->inf.process->filedescriptors.limit.soft  = ptree[leaf].filedescriptors.limit.soft;
                 s->inf.process->filedescriptors.limit.hard  = ptree[leaf].filedescriptors.limit.hard;
-                if (systeminfo.memory.size > 0) {
-                        s->inf.process->total_mem_percent = ptree[leaf].memory.usage_total >= systeminfo.memory.size ? 100. : (100. * (double)ptree[leaf].memory.usage_total / (double)systeminfo.memory.size);
-                        s->inf.process->mem_percent       = ptree[leaf].memory.usage >= systeminfo.memory.size ? 100. : (100. * (double)ptree[leaf].memory.usage / (double)systeminfo.memory.size);
+                if (System_Info.memory.size > 0) {
+                        s->inf.process->total_mem_percent = ptree[leaf].memory.usage_total >= System_Info.memory.size ? 100. : (100. * (double)ptree[leaf].memory.usage_total / (double)System_Info.memory.size);
+                        s->inf.process->mem_percent       = ptree[leaf].memory.usage >= System_Info.memory.size ? 100. : (100. * (double)ptree[leaf].memory.usage / (double)System_Info.memory.size);
                 }
                 if (ptree[leaf].read.bytes >= 0)
                         Statistics_update(&(s->inf.process->read.bytes), ptree[leaf].read.time, ptree[leaf].read.bytes);
@@ -357,7 +349,7 @@ time_t ProcessTree_getProcessUptime(pid_t pid) {
 
 
 pid_t ProcessTree_findProcess(Service_T s) {
-        ASSERT(s);
+        assert(s);
         // Test the cached PID first
         if (s->inf.process->pid > 0) {
                 errno = 0;
@@ -451,93 +443,3 @@ void ProcessTree_testMatch(char *pattern) {
         regfree(regex_comp);
         FREE(regex_comp);
 }
-
-
-//FIXME: move to standalone system class
-bool init_system_info(void) {
-        memset(&systeminfo, 0, sizeof(SystemInfo_T));
-        gettimeofday(&systeminfo.collected, NULL);
-        if (uname(&systeminfo.uname) < 0) {
-                Log_error("'%s' resource monitoring initialization error -- uname failed: %s\n", Run.system->name, STRERROR);
-                return false;
-        }
-#ifdef HAVE_COREFOUNDATION_COREFOUNDATION_H
-        CFURLRef url = CFURLCreateWithFileSystemPath(NULL, CFSTR("/System/Library/CoreServices/SystemVersion.plist"), kCFURLPOSIXPathStyle, false);
-        if (url) {
-                CFReadStreamRef stream = CFReadStreamCreateWithFile(NULL, url);
-                if (stream) {
-                        if (CFReadStreamOpen(stream)) {
-                                CFPropertyListRef propertyList = CFPropertyListCreateWithStream(NULL, stream, 0, kCFPropertyListImmutable, NULL, NULL);
-                                if (propertyList) {
-                                        CFStringRef value = CFDictionaryGetValue(propertyList, CFSTR("ProductName"));
-                                        if (value) {
-                                                CFStringGetCString(value, systeminfo.uname.sysname, sizeof(systeminfo.uname.sysname), CFStringGetSystemEncoding());
-                                        }
-                                        value = CFDictionaryGetValue(propertyList, CFSTR("ProductVersion"));
-                                        if (value) {
-                                                CFStringGetCString(value, systeminfo.uname.release, sizeof(systeminfo.uname.release), CFStringGetSystemEncoding());
-                                        }
-                                        CFRelease(propertyList);
-                                }
-                                CFReadStreamClose(stream);
-                        }
-                        CFRelease(stream);
-                }
-                CFRelease(url);
-        }
-#endif
-        systeminfo.cpu.usage.user = -1.;
-        systeminfo.cpu.usage.system = -1.;
-        systeminfo.cpu.usage.iowait = -1.;
-        return (init_process_info_sysdep());
-}
-
-
-//FIXME: move to standalone system class
-bool update_system_info() {
-        if (getloadavg_sysdep(systeminfo.loadavg, 3) == -1) {
-                Log_error("'%s' statistic error -- load average data collection failed\n", Run.system->name);
-                goto error1;
-        }
-
-        if (! used_system_memory_sysdep(&systeminfo)) {
-                Log_error("'%s' statistic error -- memory usage data collection failed\n", Run.system->name);
-                goto error2;
-        }
-        systeminfo.memory.usage.percent  = systeminfo.memory.size > 0ULL ? (100. * (double)systeminfo.memory.usage.bytes / (double)systeminfo.memory.size) : 0.;
-        systeminfo.swap.usage.percent = systeminfo.swap.size > 0ULL ? (100. * (double)systeminfo.swap.usage.bytes / (double)systeminfo.swap.size) : 0.;
-
-        if (! used_system_cpu_sysdep(&systeminfo)) {
-                Log_error("'%s' statistic error -- cpu usage data collection failed\n", Run.system->name);
-                goto error3;
-        }
-
-        if (! used_system_filedescriptors_sysdep(&systeminfo)) {
-                Log_error("'%s' statistic error -- filedescriptors usage data collection failed\n", Run.system->name);
-                goto error4;
-        }
-
-        return true;
-
-error1:
-        systeminfo.loadavg[0] = 0;
-        systeminfo.loadavg[1] = 0;
-        systeminfo.loadavg[2] = 0;
-error2:
-        systeminfo.memory.usage.bytes = 0ULL;
-        systeminfo.memory.usage.percent = 0.;
-        systeminfo.swap.usage.bytes = 0ULL;
-        systeminfo.swap.usage.percent = 0.;
-error3:
-        systeminfo.cpu.usage.user = 0.;
-        systeminfo.cpu.usage.system = 0.;
-        systeminfo.cpu.usage.iowait = 0.;
-error4:
-        systeminfo.filedescriptors.allocated = 0LL;
-        systeminfo.filedescriptors.unused = 0LL;
-        systeminfo.filedescriptors.maximum = 0LL;
-
-        return false;
-}
-
-
